@@ -2,12 +2,13 @@
  * This is GNU Go, a Go program. Contact gnugo@gnu.org, or see       *
  * http://www.gnu.org/software/gnugo/ for more information.          *
  *                                                                   *
- * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005 and 2006       *
+ * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 and 2007 *
  * by the Free Software Foundation.                                  *
  *                                                                   *
  * This program is free software; you can redistribute it and/or     *
  * modify it under the terms of the GNU General Public License as    *
- * published by the Free Software Foundation - version 2             *
+ * published by the Free Software Foundation - version 3 or          *
+ * (at your option) any later version.                               *
  *                                                                   *
  * This program is distributed in the hope that it will be useful,   *
  * but WITHOUT ANY WARRANTY; without even the implied warranty of    *
@@ -100,13 +101,14 @@ typedef unsigned char Intersection;
 
 /* Board sizes */
 
-#define DEFAULT_BOARD_SIZE 19
 
 #define MIN_BOARD          1       /* Minimum supported board size.   */
 #define MAX_BOARD         19       /* Maximum supported board size.   */
 #define MAX_HANDICAP       9       /* Maximum supported handicap.     */
 #define MAX_MOVE_HISTORY 500       /* Max number of moves remembered. */
 
+#define DEFAULT_BOARD_SIZE MAX_BOARD
+
 /* Colors and komaster states. */
 enum colors {
   EMPTY,
