@@ -2,12 +2,13 @@
  * This is GNU Go, a Go program. Contact gnugo@gnu.org, or see       *
  * http://www.gnu.org/software/gnugo/ for more information.          *
  *                                                                   *
- * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005 and 2006       *
+ * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 and 2007 *
  * by the Free Software Foundation.                                  *
  *                                                                   *
  * This program is free software; you can redistribute it and/or     *
  * modify it under the terms of the GNU General Public License as    *
- * published by the Free Software Foundation - version 2             *
+ * published by the Free Software Foundation - version 3 or          *
+ * (at your option) any later version.                               *
  *                                                                   *
  * This program is distributed in the hope that it will be useful,   *
  * but WITHOUT ANY WARRANTY; without even the implied warranty of    *
@@ -39,12 +40,14 @@ int          initial_white_captured;
 int          initial_black_captured;
 int          move_history_color[MAX_MOVE_HISTORY];
 int          move_history_pos[MAX_MOVE_HISTORY];
+Hash_data    move_history_hash[MAX_MOVE_HISTORY];
 int          move_history_pointer;
 
 float komi = 0.0;
 int handicap = 0;
 int movenum;
-int allow_suicide = 0;  /* allow opponent to make suicide moves */
+enum suicide_rules suicide_rule = FORBIDDEN;
+enum ko_rules ko_rule = SIMPLE;
 
 
 signed char shadow[BOARDMAX];
