@@ -2,12 +2,13 @@
  * This is GNU Go, a Go program. Contact gnugo@gnu.org, or see       *
  * http://www.gnu.org/software/gnugo/ for more information.          *
  *                                                                   *
- * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005 and 2006       *
+ * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 and 2007 *
  * by the Free Software Foundation.                                  *
  *                                                                   *
  * This program is free software; you can redistribute it and/or     *
  * modify it under the terms of the GNU General Public License as    *
- * published by the Free Software Foundation - version 2             *
+ * published by the Free Software Foundation - version 3 or          *
+ * (at your option) any later version.                               *
  *                                                                   *
  * This program is distributed in the hope that it will be useful,   *
  * but WITHOUT ANY WARRANTY; without even the implied warranty of    *
@@ -99,6 +100,11 @@ reset_engine()
 
   /* Set up depth values (see comments there for details). */
   set_depth_values(get_level(), 0);
+
+  /* Initialize arrays of moves which are meaningless due to
+   * static analysis of unconditional status.
+   */
+  clear_unconditionally_meaningless_moves();
 }
 
 /*
@@ -289,7 +295,9 @@ collect_move_reasons(int color)
   worm_reasons(color);
   semeai_move_reasons(color);
   owl_reasons(color);
+  cut_reasons(color);
   break_in_move_reasons(color);
+  unconditional_move_reasons(color);
 }
 
 /* 
@@ -473,13 +481,16 @@ do_genmove(int color, float pure_threat_value,
    * all missing dame points.
    */
   if (move == PASS_MOVE
-      && fill_liberty(&move, color)
-      && (!allowed_moves || allowed_moves[move])) {
-    *value = 1.0;
-    TRACE("Filling a liberty at %1m\n", move);
-    record_top_move(move, *value);
-    move_considered(move, *value);
-    time_report(1, "fill liberty", NO_MOVE, 1.0);
+      && fill_liberty(&move, color)) {
+    if (!allowed_moves || allowed_moves[move]) {
+      *value = 1.0;
+      TRACE("Filling a liberty at %1m\n", move);
+      record_top_move(move, *value);
+      move_considered(move, *value);
+      time_report(1, "fill liberty", NO_MOVE, 1.0);
+    }
+    else
+      move = PASS_MOVE;
   }
 
   /* If we're instructed to play out the aftermath or capture all dead
@@ -490,13 +501,7 @@ do_genmove(int color, float pure_threat_value,
     if (play_out_aftermath 
 	|| capture_all_dead 
 	|| (!doing_scoring && thrashing_dragon && pessimistic_score > 15.0))
-      move = aftermath_genmove(color, 0, allowed_moves);
-      
-    /* If we're instructed to capture all dead opponent stones, generate
-     * a capturing move.
-     */
-    if (move == PASS_MOVE && capture_all_dead) 
-      move = aftermath_genmove(color, 1, allowed_moves);
+      move = aftermath_genmove(color, capture_all_dead, allowed_moves);
 
     if (move != PASS_MOVE) {
       ASSERT1(is_legal(move, color), move);
