@@ -2,12 +2,13 @@
  * This is GNU Go, a Go program. Contact gnugo@gnu.org, or see       *
  * http://www.gnu.org/software/gnugo/ for more information.          *
  *                                                                   *
- * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005 and 2006       *
+ * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 and 2007 *
  * by the Free Software Foundation.                                  *
  *                                                                   *
  * This program is free software; you can redistribute it and/or     *
  * modify it under the terms of the GNU General Public License as    *
- * published by the Free Software Foundation - version 2             *
+ * published by the Free Software Foundation - version 3 or          *
+ * (at your option) any later version.                               *
  *                                                                   *
  * This program is distributed in the hope that it will be useful,   *
  * but WITHOUT ANY WARRANTY; without even the implied warranty of    *
@@ -324,6 +325,9 @@ void set_strength_data(int color, signed char safe_stones[BOARDMAX],
 		       float strength[BOARDMAX]);
 void mark_inessential_stones(int color, signed char safe_stones[BOARDMAX]);
 
+void add_cut(int apos, int bpos, int move);
+void cut_reasons(int color);
+
 void get_lively_stones(int color, signed char safe_stones[BOARDMAX]);
 int is_same_worm(int w1, int w2);
 int is_worm_origin(int w, int pos);
@@ -408,6 +412,9 @@ void compute_move_probabilities(float probabilities[BOARDMAX]);
 void register_good_attack_threat(int move, int target);
 int is_known_good_attack_threat(int move, int target);
 
+void register_known_safe_move(int move);
+int is_known_safe_move(int move);
+
 int get_attack_threats(int pos, int max_strings, int strings[]);
 int get_defense_threats(int pos, int max_strings, int strings[]);
 void get_saved_worms(int pos, signed char saved[BOARDMAX]);
@@ -432,6 +439,13 @@ int owl_strong_dragon(int pos);
 void owl_reasons(int color);
 
 void unconditional_life(int unconditional_territory[BOARDMAX], int color);
+void clear_unconditionally_meaningless_moves(void);
+void find_unconditionally_meaningless_moves(int unconditional_territory[BOARDMAX],
+					    int color);
+int unconditionally_meaningless_move(int pos, int color,
+				     int *replacement_move);
+void unconditional_move_reasons(int color);
+
 void find_superstring(int str, int *num_stones, int *stones);
 void find_superstring_conservative(int str, int *num_stones, int *stones);
 void find_superstring_liberties(int str, int *liberties, int *libs,
@@ -832,6 +846,10 @@ struct worm_data {
 
 extern struct worm_data worm[BOARDMAX];
 
+/* Unconditionally meaningless moves. */
+int meaningless_black_moves[BOARDMAX];
+int meaningless_white_moves[BOARDMAX];
+
 /* Surround cache (see surround.c) */
 
 #define MAX_SURROUND 10
