@@ -2,12 +2,13 @@
  * This is GNU Go, a Go program. Contact gnugo@gnu.org, or see       *
  * http://www.gnu.org/software/gnugo/ for more information.          *
  *                                                                   *
- * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005 and 2006       *
+ * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 and 2007 *
  * by the Free Software Foundation.                                  *
  *                                                                   *
  * This program is free software; you can redistribute it and/or     *
  * modify it under the terms of the GNU General Public License as    *
- * published by the Free Software Foundation - version 2             *
+ * published by the Free Software Foundation - version 3 or          *
+ * (at your option) any later version.                               *
  *                                                                   *
  * This program is distributed in the hope that it will be useful,   *
  * but WITHOUT ANY WARRANTY; without even the implied warranty of    *
@@ -74,6 +75,10 @@ int current_color;
 /* Attack threats that are known to be sente locally. */
 static int known_good_attack_threats[BOARDMAX][MAX_ATTACK_THREATS];
 
+/* Moves that are known to be safe (in the sense that played stones can
+ * be captured, but opponent loses much more when attempting to do so)
+ */
+static int known_safe_moves[BOARDMAX];
 
 /* Helper functions to check conditions in discard rules. */
 typedef int (*discard_condition_fn_ptr)(int pos, int what);
@@ -138,6 +143,7 @@ clear_move_reasons(void)
   }
 
   for (pos = BOARDMIN; pos < BOARDMAX; pos++) {
+    known_safe_moves[pos] = 0;
     for (k = 0; k < MAX_ATTACK_THREATS; k++)
       known_good_attack_threats[pos][k] = NO_MOVE;
   }
@@ -2023,6 +2029,30 @@ is_known_good_attack_threat(int move, int target)
   return 0;
 }
 
+/* Like documented in endgame:980, there are also moves which aren't
+ * safe by themselves, but attempting to capture these stones would
+ * result in a loss for the opponent (typically, by damezumari).
+ * Simple examples include snapbacks, but more complicated ones do
+ * exist. Following functions are helpers for the valuation processing
+ * which deal with such special cases.
+ */
+void
+register_known_safe_move(int move)
+{
+  ASSERT_ON_BOARD1(move);
+  
+  known_safe_moves[move] = 1;
+}
+
+
+int
+is_known_safe_move(int move)
+{
+  ASSERT_ON_BOARD1(move);
+  
+  return known_safe_moves[move];
+}
+
 
 /*
  * Local Variables:
