@@ -2,12 +2,13 @@
  * This is GNU Go, a Go program. Contact gnugo@gnu.org, or see       *
  * http://www.gnu.org/software/gnugo/ for more information.          *
  *                                                                   *
- * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005 and 2006       *
+ * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 and 2007 *
  * by the Free Software Foundation.                                  *
  *                                                                   *
  * This program is free software; you can redistribute it and/or     *
  * modify it under the terms of the GNU General Public License as    *
- * published by the Free Software Foundation - version 2             *
+ * published by the Free Software Foundation - version 3 or          *
+ * (at your option) any later version.                               *
  *                                                                   *
  * This program is distributed in the hope that it will be useful,   *
  * but WITHOUT ANY WARRANTY; without even the implied warranty of    *
@@ -701,6 +702,8 @@ compute_unconditional_status()
   
   for (color = WHITE; color <= BLACK; color++) {
     unconditional_life(unconditional_territory, color);
+    if (get_level() >= 10)
+      find_unconditionally_meaningless_moves(unconditional_territory, color);
 
     for (pos = BOARDMIN; pos < BOARDMAX; pos++) {
       if (!ON_BOARD(pos) || !unconditional_territory[pos])
@@ -1703,20 +1706,19 @@ defense_callback(int anchor, int color, struct pattern *pattern, int ll,
   }
 }
 
+
 void
 get_lively_stones(int color, signed char safe_stones[BOARDMAX])
 {
-  int ii;
+  int pos;
   memset(safe_stones, 0, BOARDMAX * sizeof(*safe_stones));
-  for (ii = BOARDMIN; ii < BOARDMAX; ii++)
-    ASSERT1(safe_stones[ii] == 0, ii);
-  for (ii = BOARDMIN; ii < BOARDMAX; ii++)
-    if (IS_STONE(board[ii])
-	&& worm[ii].origin == ii) {
-      if (worm[ii].attack_codes[0] == 0
-	  || (board[ii] == color
-	      && worm[ii].defense_codes[0] != 0))
-	mark_string(ii, safe_stones, 1);
+  for (pos = BOARDMIN; pos < BOARDMAX; pos++)
+    if (IS_STONE(board[pos]) && find_origin(pos) == pos) {
+      if ((stackp == 0 && worm[pos].attack_codes[0] == 0) || !attack(pos, NULL)
+	  || (board[pos] == color
+	      && ((stackp == 0 && worm[pos].defense_codes[0] != 0)
+		  || find_defense(pos, NULL))))
+	mark_string(pos, safe_stones, 1);
     }
 }
 
