@@ -2,12 +2,13 @@
  * This is GNU Go, a Go program. Contact gnugo@gnu.org, or see       *
  * http://www.gnu.org/software/gnugo/ for more information.          *
  *                                                                   *
- * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005 and 2006       *
+ * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 and 2007 *
  * by the Free Software Foundation.                                  *
  *                                                                   *
  * This program is free software; you can redistribute it and/or     *
  * modify it under the terms of the GNU General Public License as    *
- * published by the Free Software Foundation - version 2             *
+ * published by the Free Software Foundation - version 3 or          *
+ * (at your option) any later version.                               *
  *                                                                   *
  * This program is distributed in the hope that it will be useful,   *
  * but WITHOUT ANY WARRANTY; without even the implied warranty of    *
@@ -23,8 +24,11 @@
 #ifndef _DFA_H_
 #define _DFA_H_
 
-
+#if MAX_BOARD > 11
 #define DFA_MAX_BOARD		MAX_BOARD
+#else
+#define DFA_MAX_BOARD 		11
+#endif
 #define DFA_MAX_ORDER		((2 * DFA_MAX_BOARD - 1)	\
 				 * (2 * DFA_MAX_BOARD - 1))
 #define DFA_BASE		(3 * DFA_MAX_BOARD)
