@@ -2,12 +2,13 @@
  * This is GNU Go, a Go program. Contact gnugo@gnu.org, or see       *
  * http://www.gnu.org/software/gnugo/ for more information.          *
  *                                                                   *
- * Copyright 1999, 2000, 2001, 2002, 2003, 2004 and 2005             *
+ * Copyright 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006 and 2007 *
  * by the Free Software Foundation.                                  *
  *                                                                   *
  * This program is free software; you can redistribute it and/or     *
  * modify it under the terms of the GNU General Public License as    *
- * published by the Free Software Foundation - version 2             *
+ * published by the Free Software Foundation - version 3 or          *
+ * (at your option) any later version.                               *
  *                                                                   *
  * This program is distributed in the hope that it will be useful,   *
  * but WITHOUT ANY WARRANTY; without even the implied warranty of    *
@@ -447,16 +448,14 @@ int
 finish_ko_helper(int pos)
 {
   int adj, adjs[MAXCHAIN];
+  int lib;
   int k;
 
   adj = chainlinks2(pos, adjs, 1);
   for (k = 0; k < adj; k++) {
-    int aa = adjs[k];
-    int xx;
-
-    if (countstones(aa) == 1) {
-      findlib(aa, 1, &xx);
-      if (is_ko(xx, board[pos], NULL))
+    if (countstones(adjs[k]) == 1) {
+      findlib(adjs[k], 1, &lib);
+      if (is_ko(lib, board[pos], NULL))
 	return 1;
     }
   }
